/*
 * XPInstall script by Fernando Pereira Silveira
 * Feel free to copy/modify this script!
 *
 * This install script can deny extension updates, if you decide so. In case you
 * set it to deny extension updates, don't forget to customize the error message
 * located on lines 63 and 64.
 *
 * If you have any doubt, send it to fernandopsilveira@yahoo.com.br
 *
 */

// --- EDITABLE DATA BEGIN ---

const displayName = "Controle de Scripts";
const name        = "controledescripts";
const version     = "1.0.1";
const package     = "/fps/controledescripts";

const skins = ["classic", "modern"];

const locales = ["en-US", "de-DE", "es-AR", "es-ES", "fi-FI", "fr-FR", "it-IT",
                 "nl-NL", "pt-BR", "zh-CN", "zh-TW"];

const preferenceFilesPath = "defaults/preferences";

const jarName = "controledescripts.jar";

const jarHasSubfolder = false;
const allowUpdate     = false;
const silentInstall   = false;
var   profileInstall  = true;

// --- EDITABLE DATA END -----


// *** Auxiliar data ***
const appFolder = getFolder("Chrome");
const profileFolder = getFolder("Profile", "chrome");
const appUpdate = File.exists(getFolder(appFolder, jarName));
const profileUpdate = File.exists(getFolder(profileFolder, jarName));
const jarSubfolder = jarHasSubfolder ? name+"/" : "";
var chromeType = null;
var installFolder = null;
var jarFile = null;

// *** Auxiliar routines ***
if (silentInstall) logComment("silent install mode");

if (appUpdate || profileUpdate) {
	if (allowUpdate) {
		profileInstall = profileUpdate;
		logComment("previous version detected: updating "+(profileInstall ? "user profile" : "app folder"));

		if (!silentInstall)
			alert("Updating "+displayName+" to version "+version+" on "+(profileInstall ? "user profile" : "application folder")+".");

		setEnvironment();
		doInstall();
	}
	else {
		if (!silentInstall)
			alert("Cannot install "+displayName+" "+version+". Please uninstall your previous version first.\n"
			    + "(If you don't know how to uninstall it, visit controledescripts.mozdev.org/help/)");

		logComment("cancelling install: extension update denied");
		cancelInstall();
	}
}
else {
	if (!silentInstall)
		profileInstall = confirm("Do you want to install "+displayName+" "+version+" just for this profile?\n"
		                       + "Cancel will install it globally (all profiles).\n\n"
		                       + "(If you don't know what does this mean, click OK)");

	setEnvironment();
	doInstall();
}

// *** Installer ***

function setEnvironment() {
	chromeType = profileInstall ? PROFILE_CHROME : DELAYED_CHROME;
	installFolder = profileInstall ? profileFolder : appFolder;
	jarFile = getFolder(installFolder, jarName);
}

function doInstall() {
	var error;

	// Begin install
	error = initInstall(displayName, package, version);
	logComment("installing to "+(profileInstall ? "user profile" : "app folder")+": "+installFolder);
	logComment("initInstall: "+error);

	// Copy JAR file
	if (error == SUCCESS) {
		error = addFile("package", version, "chrome/"+jarName, installFolder, null);
		logComment("addFile() for JAR package returned: "+error);
	}

	// Copy preferences files
	if (error == SUCCESS && preferenceFilesPath) {
		error = addDirectory("preferences", version, preferenceFilesPath, getFolder("Program","defaults/pref/"), null);
		logComment("addDirectory() for Defaults returned: "+error);
	}

	if (error == SUCCESS) {
		// Register content
		registerChrome(CONTENT | chromeType, jarFile, "content/"+jarSubfolder);

		// Register locales
		for (thisOne in locales)
			registerChrome(LOCALE | chromeType, jarFile, "locale/"+locales[thisOne]+"/"+jarSubfolder);

		// Register skins
		for (var thisOne in skins)
			registerChrome(SKIN | chromeType, jarFile, "skin/"+skins[thisOne]+"/"+jarSubfolder);

		// Finish install
		error = performInstall();
		logComment("performInstall() returned: "+error);

		if (!silentInstall)
			alert((error == SUCCESS || error == REBOOT_NEEDED) ? displayName+" "+version+" has been"+(profileInstall ? "" : " globally")+" installed successfully!"+(error == REBOOT_NEEDED ? "\nRestart SeaMonkey to complete the process." : "") : "Failed to install "+displayName+"!\n\nPlease, contact the author and inform the following error code: "+error+"x1.");
	}
	else {
		if (!silentInstall) {
			var msg = "Couldn't install "+displayName+"!";

			switch (error) {
				case -202: msg += "\nCause: Access Denied. You probably have no write access to chrome."; break;
				case -215: msg += "\nCause: Read-only. You probably have no write access to chrome."; break;
				case -235: msg += "\nCause: Not enough disk space to install."; break;
				case -299: msg += "\nCause: Insufficient memory for operation."; break;
				default: msg += "\n\nPlease, contact the author and inform the following error code: "+error+"x0.";
			}

			alert(msg);
		}

		logComment("cancelInstall due to error: "+error);
		cancelInstall(error);
	}
}
